/*
date: 4.29.2019

purpose: create balance table regressing baseline charateristics on randomization
		
input: 
1) "$drive\3output_data\oakland_analysis_final.dta"
2) "$drive\3output_data\oakland_analysis_lenient.dta" - for attrition measure

output: "$drive\6tables\table2_balance.csv"

author: MF

*/


clear
set more off 
cap log close 

log using "$drive\4log\table2_balance.smcl", replace


global baseline   good_sa_health any_health_prob ER_2years nights_hosp_2years med_mistrust ///
				  has_PCP uninsured age married unemployed HSless low_income 
				  

	use "$drive\3output_data\oakland_analysis_final.dta", clear		
	keep if tag == 1
	
	est clear 
	foreach var of global baseline {
		replace `var' = . if `var' == -9
	
		qui reg `var' white5 white10 black0 black5 black10, r
			est store `var'_1	

		test white5=white10=black0=black5=black10=0
			estadd scalar joint_Ftest = r(F)
			estadd scalar F_pvalue = r(p)
		
		sum `var' if white0 == 1
			estadd scalar control_mean = r(mean)
			estadd scalar mean_SD = r(sd)
	}

use "$drive\3output_data\oakland_analysis_lenient.dta", clear	
	
	keep if tag == 1 & black_resp == 1 & women != 1
		reg attrit white5 white10 black0 black5 black10, r
			est store `var'_1	

		test white5=white10=black0=black5=black10=0
			estadd scalar joint_Ftest = r(F)
			estadd scalar F_pvalue = r(p)
		
		sum attrit if white0 == 1
			estadd scalar control_mean = r(mean)
			estadd scalar mean_SD = r(sd)
	
	esttab  _all using "$drive\6tables\table2_balance.csv", stats(control_mean mean_SD joint_Ftest F_pvalue N)  ///
			keep(white5 white10 black0 black5 black10) se b(3) nostar replace 
			
log  close			
