/*
date: 4.29.2019

purpose: main results for pre, post, and delta with RI p-values
		
input: 
1) "$drive\3output_data\oakland_analysis_final.dta"
2) "$drive\3output_data\race_combinations_6black.dta" - RI permutations of black dr

output: 
1) "$drive\6tables\table3_main.csv"

author: MF

*requires ritest.ado*

*/

clear all
set more off 
cap log close 
set maxvar 20000

log using "$drive\4log\table3_main.smcl", replace

global tests			"bp bmi dia cho flu share4 shr_invasive"
global type		 		"pre post delta" 

	est clear
		foreach y of global tests  {
			foreach stage of global type {
				use "$drive\3output_data\oakland_analysis_final.dta", clear		
		
*1) cluster standard errors		
				reg `stage'_`y' 		black_dr sl5 sl10 if tag == 1, cluster(doctor_id)
					est store `stage'_`y'1					

*2) random inference - 14 choose 6 black doctors (3003) 
				ritest black_dr _b[black_dr], reps(3003) samplingsourcefile("$drive\3output_data\race_combinations_6black.dta") ///
								samplingmatchvar(doctor_id): ///
								reg `stage'_`y' black_dr sl5 sl10 if tag == 1
					local temp = el(r(p),1,1)
					est restore `stage'_`y'1
					estadd scalar ri_p = `temp'
					
*3) control group means					
				if "`y'" == "flu" {
					sum `stage'_`y' if black_dr == 0 & sl0 == 1
				}	
				else {
					sum `stage'_`y' if black_dr == 0
				}	
					estadd scalar control_mean = r(mean)		
			}
		}												
				
		esttab pre* post* delta* using "$drive\6tables\table3_main.csv", keep(black_dr sl5 sl10) nostar ///
					stats(ri_p control_mean N) se b(3) replace  	
					
 log close 

